==> apigateway-1.15.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/apigateway/RequestValidatorOptions.java <==
package software.amazon.awscdk.services.apigateway;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.19.0 (build 7c562bc)", date = "2019-10-28T12:27:21.936Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface RequestValidatorOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * The name of this request validator.
     * 
     * Default: None
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getRequestValidatorName();

    /**
     * Indicates whether to validate the request body according to the configured schema for the targeted API and method.
     * 
     * Default: false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.Boolean getValidateRequestBody();

    /**
     * Indicates whether to validate request parameters.
     * 
     * Default: false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.Boolean getValidateRequestParameters();

    /**
     * @return a {@link Builder} of {@link RequestValidatorOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link RequestValidatorOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder {
        private java.lang.String requestValidatorName;
        private java.lang.Boolean validateRequestBody;
        private java.lang.Boolean validateRequestParameters;

        /**
         * Sets the value of RequestValidatorName
         * @param requestValidatorName The name of this request validator.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder requestValidatorName(java.lang.String requestValidatorName) {
            this.requestValidatorName = requestValidatorName;
            return this;
        }

        /**
         * Sets the value of ValidateRequestBody
         * @param validateRequestBody Indicates whether to validate the request body according to the configured schema for the targeted API and method.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder validateRequestBody(java.lang.Boolean validateRequestBody) {
            this.validateRequestBody = validateRequestBody;
            return this;
        }

        /**
         * Sets the value of ValidateRequestParameters
         * @param validateRequestParameters Indicates whether to validate request parameters.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder validateRequestParameters(java.lang.Boolean validateRequestParameters) {
            this.validateRequestParameters = validateRequestParameters;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link RequestValidatorOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public RequestValidatorOptions build() {
            return new Jsii$Proxy(requestValidatorName, validateRequestBody, validateRequestParameters);
        }
    }

    /**
     * An implementation for {@link RequestValidatorOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements RequestValidatorOptions {
        private final java.lang.String requestValidatorName;
        private final java.lang.Boolean validateRequestBody;
        private final java.lang.Boolean validateRequestParameters;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.requestValidatorName = this.jsiiGet("requestValidatorName", java.lang.String.class);
            this.validateRequestBody = this.jsiiGet("validateRequestBody", java.lang.Boolean.class);
            this.validateRequestParameters = this.jsiiGet("validateRequestParameters", java.lang.Boolean.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(java.lang.String requestValidatorName, java.lang.Boolean validateRequestBody, java.lang.Boolean validateRequestParameters) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.requestValidatorName = requestValidatorName;
            this.validateRequestBody = validateRequestBody;
            this.validateRequestParameters = validateRequestParameters;
        }

        @Override
        public java.lang.String getRequestValidatorName() {
            return this.requestValidatorName;
        }

        @Override
        public java.lang.Boolean getValidateRequestBody() {
            return this.validateRequestBody;
        }

        @Override
        public java.lang.Boolean getValidateRequestParameters() {
            return this.validateRequestParameters;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            if (this.getRequestValidatorName() != null) {
                obj.set("requestValidatorName", om.valueToTree(this.getRequestValidatorName()));
            }
            if (this.getValidateRequestBody() != null) {
                obj.set("validateRequestBody", om.valueToTree(this.getValidateRequestBody()));
            }
            if (this.getValidateRequestParameters() != null) {
                obj.set("validateRequestParameters", om.valueToTree(this.getValidateRequestParameters()));
            }
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            RequestValidatorOptions.Jsii$Proxy that = (RequestValidatorOptions.Jsii$Proxy) o;

            if (this.requestValidatorName != null ? !this.requestValidatorName.equals(that.requestValidatorName) : that.requestValidatorName != null) return false;
            if (this.validateRequestBody != null ? !this.validateRequestBody.equals(that.validateRequestBody) : that.validateRequestBody != null) return false;
            return this.validateRequestParameters != null ? this.validateRequestParameters.equals(that.validateRequestParameters) : that.validateRequestParameters == null;
        }

        @Override
        public int hashCode() {
            int result = this.requestValidatorName != null ? this.requestValidatorName.hashCode() : 0;
            result = 31 * result + (this.validateRequestBody != null ? this.validateRequestBody.hashCode() : 0);
            result = 31 * result + (this.validateRequestParameters != null ? this.validateRequestParameters.hashCode() : 0);
            return result;
        }
    }
}

==> apigateway-1.16.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/apigateway/RequestValidatorOptions.java <==
package software.amazon.awscdk.services.apigateway;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.20.2 (build faba0be)", date = "2019-11-11T17:17:51.611Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.apigateway.$Module.class, fqn = "@aws-cdk/aws-apigateway.RequestValidatorOptions")
@software.amazon.jsii.Jsii.Proxy(RequestValidatorOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface RequestValidatorOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * The name of this request validator.
     * 
     * Default: None
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default java.lang.String getRequestValidatorName() {
        return null;
    }

    /**
     * Indicates whether to validate the request body according to the configured schema for the targeted API and method.
     * 
     * Default: false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default java.lang.Boolean getValidateRequestBody() {
        return null;
    }

    /**
     * Indicates whether to validate request parameters.
     * 
     * Default: false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default java.lang.Boolean getValidateRequestParameters() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link RequestValidatorOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link RequestValidatorOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder {
        private java.lang.String requestValidatorName;
        private java.lang.Boolean validateRequestBody;
        private java.lang.Boolean validateRequestParameters;

        /**
         * Sets the value of RequestValidatorName
         * @param requestValidatorName The name of this request validator.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder requestValidatorName(java.lang.String requestValidatorName) {
            this.requestValidatorName = requestValidatorName;
            return this;
        }

        /**
         * Sets the value of ValidateRequestBody
         * @param validateRequestBody Indicates whether to validate the request body according to the configured schema for the targeted API and method.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder validateRequestBody(java.lang.Boolean validateRequestBody) {
            this.validateRequestBody = validateRequestBody;
            return this;
        }

        /**
         * Sets the value of ValidateRequestParameters
         * @param validateRequestParameters Indicates whether to validate request parameters.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder validateRequestParameters(java.lang.Boolean validateRequestParameters) {
            this.validateRequestParameters = validateRequestParameters;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link RequestValidatorOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public RequestValidatorOptions build() {
            return new Jsii$Proxy(requestValidatorName, validateRequestBody, validateRequestParameters);
        }
    }

    /**
     * An implementation for {@link RequestValidatorOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements RequestValidatorOptions {
        private final java.lang.String requestValidatorName;
        private final java.lang.Boolean validateRequestBody;
        private final java.lang.Boolean validateRequestParameters;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.requestValidatorName = this.jsiiGet("requestValidatorName", java.lang.String.class);
            this.validateRequestBody = this.jsiiGet("validateRequestBody", java.lang.Boolean.class);
            this.validateRequestParameters = this.jsiiGet("validateRequestParameters", java.lang.Boolean.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.String requestValidatorName, final java.lang.Boolean validateRequestBody, final java.lang.Boolean validateRequestParameters) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.requestValidatorName = requestValidatorName;
            this.validateRequestBody = validateRequestBody;
            this.validateRequestParameters = validateRequestParameters;
        }

        @Override
        public java.lang.String getRequestValidatorName() {
            return this.requestValidatorName;
        }

        @Override
        public java.lang.Boolean getValidateRequestBody() {
            return this.validateRequestBody;
        }

        @Override
        public java.lang.Boolean getValidateRequestParameters() {
            return this.validateRequestParameters;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getRequestValidatorName() != null) {
                data.set("requestValidatorName", om.valueToTree(this.getRequestValidatorName()));
            }
            if (this.getValidateRequestBody() != null) {
                data.set("validateRequestBody", om.valueToTree(this.getValidateRequestBody()));
            }
            if (this.getValidateRequestParameters() != null) {
                data.set("validateRequestParameters", om.valueToTree(this.getValidateRequestParameters()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-apigateway.RequestValidatorOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            RequestValidatorOptions.Jsii$Proxy that = (RequestValidatorOptions.Jsii$Proxy) o;

            if (this.requestValidatorName != null ? !this.requestValidatorName.equals(that.requestValidatorName) : that.requestValidatorName != null) return false;
            if (this.validateRequestBody != null ? !this.validateRequestBody.equals(that.validateRequestBody) : that.validateRequestBody != null) return false;
            return this.validateRequestParameters != null ? this.validateRequestParameters.equals(that.validateRequestParameters) : that.validateRequestParameters == null;
        }

        @Override
        public int hashCode() {
            int result = this.requestValidatorName != null ? this.requestValidatorName.hashCode() : 0;
            result = 31 * result + (this.validateRequestBody != null ? this.validateRequestBody.hashCode() : 0);
            result = 31 * result + (this.validateRequestParameters != null ? this.validateRequestParameters.hashCode() : 0);
            return result;
        }
    }
}
